@@ -210,7 +210,7 @@ net_send_request (gpointer gdata)
 	
 	curl_easy_setopt (session, CURLOPT_WRITEFUNCTION, net_write_cb);
 	curl_easy_setopt (session, CURLOPT_WRITEDATA, memory);
-	curl_easy_setopt (session, CURLOPT_URL, "http://www.dropline.net/gnome/DroplineFiles2b");
+	curl_easy_setopt (session, CURLOPT_URL, "http://www.dropline.net/gnome/DroplineFiles2c");
 	curl_easy_setopt (session, CURLOPT_NOPROGRESS, TRUE);
 	curl_easy_setopt (session, CURLOPT_USERAGENT, "Dropline Alert " VERSION);
 //	curl_easy_setopt (session, CURLOPT_TIMEOUT, 45);
